<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>AboutBox</name>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="33"/>
        <source>About Q Light Controller Plus</source>
        <translation>O aplikaci Q Light Controller Plus</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="88"/>
        <source>Contributors</source>
        <translation>Spolupracovníci</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="135"/>
        <source>This application is licensed under the terms of the Apache 2.0 license.</source>
        <translation>Tato aplikace je licencována podle licence Apache 2.0.</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="42"/>
        <source>and contributors:</source>
        <translation>a spolupracovníci:</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="43"/>
        <source>Website: %1</source>
        <translation>Web: %1</translation>
    </message>
</context>
<context>
    <name>AddChannelsDialog</name>
    <message>
        <location filename="addchannelsdialog.ui" line="33"/>
        <source>Fixture Mode Channels Editor</source>
        <translation>Editor režimu kanálů zařízení</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="114"/>
        <source>Available channels</source>
        <oldsource>All channels</oldsource>
        <translation>Dostupné kanály</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="106"/>
        <location filename="addchannelsdialog.ui" line="135"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="121"/>
        <source>Mode channels</source>
        <translation>Režimy kanálů</translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="app.cpp" line="123"/>
        <source>Unrecognized file extension: %1</source>
        <translation>Neznámý typ souboru: %1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="147"/>
        <source>Fixture loading failed</source>
        <translation>Načítání zařízení selhalo</translation>
    </message>
    <message>
        <location filename="app.cpp" line="148"/>
        <source>Unable to load fixture definition: </source>
        <translation>Nelze načíst definici zařízení:</translation>
    </message>
    <message>
        <location filename="app.cpp" line="242"/>
        <source>&amp;New</source>
        <translation>&amp;Nový</translation>
    </message>
    <message>
        <location filename="app.cpp" line="243"/>
        <source>CTRL+N</source>
        <comment>File|New</comment>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <location filename="app.cpp" line="248"/>
        <source>&amp;Open</source>
        <translation>&amp;Otevřít</translation>
    </message>
    <message>
        <location filename="app.cpp" line="249"/>
        <source>CTRL+O</source>
        <comment>File|Open</comment>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <location filename="app.cpp" line="254"/>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <location filename="app.cpp" line="255"/>
        <source>CTRL+S</source>
        <comment>File|Save</comment>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <location filename="app.cpp" line="260"/>
        <source>Save &amp;As...</source>
        <translation>Uložit &amp;Jako...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="261"/>
        <source>CTRL+SHIFT+S</source>
        <comment>File|Save As...</comment>
        <translation>CTRL+SHIFT+S</translation>
    </message>
    <message>
        <location filename="app.cpp" line="266"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quit</translation>
    </message>
    <message>
        <location filename="app.cpp" line="267"/>
        <source>CTRL+Q</source>
        <comment>File|Quit</comment>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <location filename="app.cpp" line="273"/>
        <source>Index</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <location filename="app.cpp" line="274"/>
        <source>SHIFT+F1</source>
        <comment>Help|Index</comment>
        <translation>SHIFT+F1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="279"/>
        <source>About Fixture Definition Editor...</source>
        <translation>O aplikaci Editor definice zařízení...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="284"/>
        <source>About Qt...</source>
        <translation>O aplikaci Qt...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="311"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="app.cpp" line="321"/>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <location filename="app.cpp" line="359"/>
        <source>Open a fixture definition</source>
        <translation>Otevřít definici zařízení</translation>
    </message>
</context>
<context>
    <name>CapabilityWizard</name>
    <message>
        <location filename="capabilitywizard.ui" line="33"/>
        <source>Capability Wizard</source>
        <translation>Průvodce funkcemi</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="39"/>
        <source>Values</source>
        <translation>Hodnoty</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="45"/>
        <source>Start</source>
        <translation>Počátek</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="52"/>
        <source>The starting DMX value</source>
        <translation>Počáteční DMX hodnota</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="62"/>
        <source>Width</source>
        <translation>Šířka</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="69"/>
        <source>Number of values per capability</source>
        <translation>Počet hodnot pro jednotlivé funkce zařízení</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="85"/>
        <source>Amount</source>
        <translation>Množství</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="92"/>
        <source>Number of capabilities to create</source>
        <translation>Počet funkčních možností k vytvoření</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="108"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="114"/>
        <source>The common base name for all capabilities. Use hash &apos;#&apos; to create a running number.</source>
        <translation>Souhrnné základní pojmenování pro všechny funkční možnosti. Použijte # pro vytvoření číselné posloupnosti.</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="117"/>
        <source>Capability #</source>
        <translation>Funkce #</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="127"/>
        <source>Sample</source>
        <translation>Ukázka</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="133"/>
        <source>A list of capabilities that would be created with these settings</source>
        <translation>Seznam funkcí který bude vytvořen s tímto nastavením</translation>
    </message>
</context>
<context>
    <name>DocBrowser</name>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="105"/>
        <source>%1 - Document Browser</source>
        <translation>%1 - Prohlížeč dokumentů</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="127"/>
        <source>Backward</source>
        <translation>Dozadu</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="128"/>
        <source>Forward</source>
        <translation>Dopředu</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="129"/>
        <source>Index</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="130"/>
        <source>About Qt</source>
        <translation>O aplikaci Qt</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="131"/>
        <source>Close this window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditChannel</name>
    <message>
        <location filename="editchannel.ui" line="33"/>
        <source>Edit Channel</source>
        <translation>Upravit kanály</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="114"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Capability overlapping detected. Please fix.&lt;/b&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="198"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="240"/>
        <source>Default value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="253"/>
        <source>Type</source>
        <translation type="unfinished">Typ</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="260"/>
        <location filename="editchannel.ui" line="303"/>
        <source>Preset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="267"/>
        <source>The name of this channel</source>
        <translation>Název tohoto kanálu</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="274"/>
        <source>Role</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="336"/>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="360"/>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="387"/>
        <source>Value 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="401"/>
        <source>Value 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="430"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="227"/>
        <source>The group this channel belongs to</source>
        <translation>Skupina kam tento kanál patří</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="322"/>
        <source>Picture</source>
        <translation>Obrázek</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="283"/>
        <source>Coarse (MSB)</source>
        <translation>Hrubý (MSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="290"/>
        <source>Fine (LSB)</source>
        <translation>Jemný (LSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="55"/>
        <source>Capabilities</source>
        <translation>Funkce</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="90"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Minimum value</source>
        <translation>Minimální hodnota</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="95"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Maximum value</source>
        <translation>Maximální hodnota</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="100"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="154"/>
        <source>Remove the selected capability</source>
        <translation>Odebrat zvolenou funkci</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="121"/>
        <source>Capability wizard</source>
        <translation>Průvodce funkcemi</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="93"/>
        <source>Edit Channel: </source>
        <translation>Upravit kanál:</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="481"/>
        <source>Overlapping values</source>
        <translation>Hodnoty se překrývají</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="498"/>
        <source>Open Gobo File</source>
        <translation>Otevřít soubor Gobo</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="501"/>
        <source>Gobo pictures</source>
        <translation>Gobo obrázky</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="615"/>
        <source>Missing resources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="616"/>
        <source>Some gobos are missing:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="482"/>
        <source>Some capabilities could not be created because of overlapping values.</source>
        <translation>Některá funkce nemůže být vytvořena z důvodu překryvu některých hodnot.</translation>
    </message>
</context>
<context>
    <name>EditHead</name>
    <message>
        <location filename="edithead.ui" line="33"/>
        <source>Edit Head</source>
        <translation>Upravit Hlavu</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="52"/>
        <source>Channel</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="57"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
</context>
<context>
    <name>EditMode</name>
    <message>
        <location filename="editmode.ui" line="33"/>
        <source>Edit Mode</source>
        <translation>Upravit režim</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="39"/>
        <source>Mode Name</source>
        <translation>Název režimu</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="53"/>
        <source>Channels</source>
        <translation>Kanály</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="78"/>
        <source>Number</source>
        <translation>Číslo</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="83"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="91"/>
        <source>Add channel(s) to this mode</source>
        <translation>Přidat kanál(y) do tohoto režimu</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="111"/>
        <source>Remove the selected channel</source>
        <translation>Odebrat zvolený kanál</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="131"/>
        <source>Raise the selected channel</source>
        <translation>Posunout kanál výše</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="151"/>
        <source>Lower the selected channel</source>
        <translation>Posunout kanál níže</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="185"/>
        <source>Heads</source>
        <translation>Hlavy</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="198"/>
        <source>Head</source>
        <translation>Hlava</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="206"/>
        <source>Compose a new head</source>
        <translation>Zvolte novou hlavu</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="226"/>
        <source>Remove the selected head</source>
        <translation>Odebrat zvolenou hlavu</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="246"/>
        <source>Edit the channels that belong to the selected head</source>
        <translation>Upravit kanály které patří ke zvolené hlavě</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="266"/>
        <source>Raise the selected head</source>
        <translation>Posunout zvolenou hlavu výše</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="286"/>
        <source>Lower the selected head</source>
        <translation>Posunout zvolenou hlavu níže</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="320"/>
        <source>Physical</source>
        <translation>Fyzické vlastnosti</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="330"/>
        <source>Use global settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="340"/>
        <source>Override global settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditPhysical</name>
    <message>
        <location filename="editphysical.ui" line="277"/>
        <source>Bulb</source>
        <translation>Žárovka</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="45"/>
        <location filename="editphysical.ui" line="283"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="515"/>
        <source>Lumens</source>
        <translation>Lumenů</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="535"/>
        <source>Colour Temp (K)</source>
        <translation>Teplota barev (K)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="708"/>
        <source>Dimensions</source>
        <translation>Rozměry</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="784"/>
        <source>Weight</source>
        <translation>Váha</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="714"/>
        <source>kg</source>
        <translation>kg</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="724"/>
        <source>Width</source>
        <translation>Šířka</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="734"/>
        <location filename="editphysical.ui" line="754"/>
        <location filename="editphysical.ui" line="774"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="744"/>
        <source>Height</source>
        <translation>Výška</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="764"/>
        <source>Depth</source>
        <translation>Hloubka</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="39"/>
        <source>Head(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="630"/>
        <source>Lens</source>
        <translation>Objektiv</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="636"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="665"/>
        <source>Min Degrees</source>
        <translation>Min úhel</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="672"/>
        <source>Max Degrees</source>
        <translation>Max úhel</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="79"/>
        <source>Pan Max Degrees</source>
        <translation>Max úhel otočení</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="96"/>
        <source>Tilt Max Degrees</source>
        <translation>Max úhled zdvyhu</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="113"/>
        <source>Layout
(Columns x Rows)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="158"/>
        <source>Electrical</source>
        <translation>Elektrické vlastnosti</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="164"/>
        <source>Power Consumption</source>
        <translation>Spotřeba energie</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="174"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="184"/>
        <source>DMX Connector</source>
        <translation>DMX konektor</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="241"/>
        <source>Copy physical information to clipboard</source>
        <translation>Kopírovat informace do schránky</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="258"/>
        <source>Paste physical information from clipboard</source>
        <translation>Vložit informace ze schránky</translation>
    </message>
</context>
<context>
    <name>FixtureEditor</name>
    <message>
        <location filename="fixtureeditor.ui" line="33"/>
        <source>Fixture</source>
        <translation>Zařízení</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="43"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="55"/>
        <source>Manufacturer</source>
        <translation>Výrobce</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="68"/>
        <source>The manufacturer name for this fixture (e.g. Martin)</source>
        <translation>Název výrobce tohoto zařízení (např. Martin)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="75"/>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="88"/>
        <source>The model name for this fixture (e.g. MAC250)</source>
        <translation>Název modelu tohoto zařízená (např. MAC250)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="95"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="108"/>
        <source>The general type of this fixture</source>
        <translation>Obecný typ tohoto zařízení</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="226"/>
        <source>LED Bar (Beams)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="235"/>
        <source>LED Bar (Pixels)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="247"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="254"/>
        <source>The name of the author of this fixture definition</source>
        <translation>Jméno autora této definice zařízení</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="298"/>
        <location filename="fixtureeditor.ui" line="498"/>
        <source>Channels</source>
        <translation>Kanály</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="320"/>
        <location filename="fixtureeditor.ui" line="493"/>
        <source>Name</source>
        <translation>Jméno</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="325"/>
        <source>Group</source>
        <translation>Skupina</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="333"/>
        <source>Add a channel</source>
        <translation>Přidat kanál</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="353"/>
        <source>Remove the selected channel</source>
        <translation>Odebrat zvolený kanál</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="373"/>
        <source>Edit the selected channel</source>
        <translation>Upravit zvolený kanál</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="400"/>
        <source>Copy the selected channel to the clipboard</source>
        <translation>Kopírovat zvolený kanál do schránky</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="420"/>
        <source>Paste the channel in clipboard to this fixture</source>
        <translation>Vložit kanál ze schránky do tohoto zařízení</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="453"/>
        <source>Open/close all channel items</source>
        <translation>Otevřít/zavřít všechny položky kanálu</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="474"/>
        <source>Modes</source>
        <translation>Režimy</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="503"/>
        <source>Heads</source>
        <translation>Hlavy</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="511"/>
        <source>Add a mode</source>
        <translation>Přidat režim</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="531"/>
        <source>Remove the selected mode</source>
        <translation>Odebrat zvolený režim</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="551"/>
        <source>Edit the selected mode</source>
        <translation>Upravit zvolený režim</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="578"/>
        <source>Create a copy of the selected mode</source>
        <translation>Vytvořit kopii zvoleného režimu</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="611"/>
        <source>Open/close all mode items</source>
        <translation>Otevřít/zavřít všechny položky režimu</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="632"/>
        <source>Aliases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="650"/>
        <source>In mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="667"/>
        <source>Add a new alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="687"/>
        <source>with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="694"/>
        <source>replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="711"/>
        <location filename="fixtureeditor.ui" line="764"/>
        <source>Alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="716"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="721"/>
        <source>Base channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="726"/>
        <source>Override channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="744"/>
        <source>Remove the currently selected alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="275"/>
        <source>Physical</source>
        <translation type="unfinished">Fyzické vlastnosti</translation>
    </message>
</context>
<context>
    <name>QLCFixtureEditor</name>
    <message>
        <location filename="fixtureeditor.cpp" line="207"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="208"/>
        <source>Do you want to save changes to fixture
&quot;%1&quot;
before closing?</source>
        <translation>Přejete si uložit změny v zařízení
&quot;%1&quot;
před uzavřením?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="237"/>
        <location filename="fixtureeditor.cpp" line="247"/>
        <source>Missing important information</source>
        <translation>Chybí důležité informace</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="238"/>
        <source>Missing manufacturer name.
Unable to save fixture.</source>
        <translation>Chybí jméno výrobce.
Nelze uložit zařízení.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="248"/>
        <source>Missing fixture model name.
Unable to save fixture.</source>
        <translation>Chybí jméno modelu zařízení.
Nelze uložit zařízení.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="278"/>
        <location filename="fixtureeditor.cpp" line="337"/>
        <source>Fixture saving failed</source>
        <translation>Ukládání zařízení selhalo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="279"/>
        <location filename="fixtureeditor.cpp" line="338"/>
        <source>Unable to save fixture definition:
%1</source>
        <translation>Nelze uložit definici zařízení:
%1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="294"/>
        <source>Save fixture definition</source>
        <translation>Uložit definici zařízení</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="371"/>
        <source>New Fixture</source>
        <translation>Nové zařízení</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="448"/>
        <location filename="fixtureeditor.cpp" line="534"/>
        <source>Channel already exists</source>
        <translation>Kanál již existuje</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="449"/>
        <location filename="fixtureeditor.cpp" line="535"/>
        <source>A channel by the name &quot;%1&quot; already exists!</source>
        <translation>Kanál se jménem &quot;%1&quot; již existuje!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="456"/>
        <location filename="fixtureeditor.cpp" line="541"/>
        <source>Channel has no name</source>
        <translation>Kanál nemá jméno</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="457"/>
        <location filename="fixtureeditor.cpp" line="542"/>
        <source>You must give the channel a descriptive name!</source>
        <translation>Musíte pojmenovat tento kanál!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="494"/>
        <source>Are you sure you wish to remove channel: %1?</source>
        <translation>Opravdu chcete odebrat kanál: %1?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="813"/>
        <source>Are you sure you wish to remove mode: %1?</source>
        <translation>Opravdu chcete odebrat režim: %1?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="654"/>
        <location filename="fixtureeditor.cpp" line="689"/>
        <location filename="fixtureeditor.cpp" line="914"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="655"/>
        <location filename="fixtureeditor.cpp" line="691"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="656"/>
        <location filename="fixtureeditor.cpp" line="693"/>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="657"/>
        <location filename="fixtureeditor.cpp" line="695"/>
        <location filename="fixtureeditor.cpp" line="920"/>
        <source>Remove</source>
        <translation>Odebrat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="668"/>
        <source>Channels</source>
        <translation>Kanály</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="766"/>
        <location filename="fixtureeditor.cpp" line="775"/>
        <source>Unable to add mode</source>
        <translation>Režim nelze přidat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="767"/>
        <source>Another mode by that name already exists</source>
        <translation>Režim stejného jména již existuje</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="776"/>
        <source>You must give a name to the mode</source>
        <translation>Musíte zadat nejaké jméno pro tento režim</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="812"/>
        <source>Remove Mode</source>
        <translation>Odebrat režim</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="860"/>
        <source>Rename new mode</source>
        <translation>Přejmenovat nový režim</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="861"/>
        <source>Give a unique name for the mode</source>
        <translation>Zadejte jedinečné jméno pro tento režim</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="863"/>
        <source>Copy of %1</source>
        <translation>Kopie z %1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="873"/>
        <source>Invalid name</source>
        <translation>Neplatné jméno</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="874"/>
        <source>Another mode by that name already exists.</source>
        <translation>Jiný režim tohoto jména již existuje.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="917"/>
        <source>Clone</source>
        <translation>Duplikovat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="925"/>
        <source>Modes</source>
        <translation>Režimy</translation>
    </message>
</context>
</TS>
